summaryrefslogtreecommitdiffstats
path: root/kdejava/koala/org/kde/koala/KURLDrag.java
diff options
context:
space:
mode:
Diffstat (limited to 'kdejava/koala/org/kde/koala/KURLDrag.java')
-rw-r--r--kdejava/koala/org/kde/koala/KURLDrag.java52
1 files changed, 26 insertions, 26 deletions
diff --git a/kdejava/koala/org/kde/koala/KURLDrag.java b/kdejava/koala/org/kde/koala/KURLDrag.java
index 63db342f..45e00e3d 100644
--- a/kdejava/koala/org/kde/koala/KURLDrag.java
+++ b/kdejava/koala/org/kde/koala/KURLDrag.java
@@ -2,17 +2,17 @@
package org.kde.koala;
import org.kde.qt.Qt;
-import org.kde.qt.QMimeSourceInterface;
+import org.kde.qt.TQMimeSourceInterface;
import org.kde.qt.QtSupport;
import java.util.ArrayList;
-import org.kde.qt.QMimeSource;
-import org.kde.qt.QWidget;
-import org.kde.qt.QUriDrag;
+import org.kde.qt.TQMimeSource;
+import org.kde.qt.TQWidget;
+import org.kde.qt.TQUriDrag;
/**
- This class is to be used instead of QUriDrag when using KURL.
- The reason is: QUriDrag (and the XDND/W3C standards) expect URLs to
+ This class is to be used instead of TQUriDrag when using KURL.
+ The reason is: TQUriDrag (and the XDND/W3C standards) expect URLs to
be encoded in UTF-8 (unicode), but KURL uses the current locale
by default.
The other reasons for using this class are:
@@ -24,36 +24,36 @@ import org.kde.qt.QUriDrag;
<li>
it has support for metadata, shipped as part of the dragobject
This is important, for instance to set a correct HTTP referrer (some websites
- require it for downloading e.g. an image).
+ retquire it for downloading e.g. an image).
</li>
To create a drag object, use the KURLDrag constructor.
- To handle drops, use QUriDrag.canDecode() and KURLDrag.decode()
- @short This class is to be used instead of QUriDrag when using KURL.
+ To handle drops, use TQUriDrag.canDecode() and KURLDrag.decode()
+ @short This class is to be used instead of TQUriDrag when using KURL.
*/
-public class KURLDrag extends QUriDrag {
+public class KURLDrag extends TQUriDrag {
protected KURLDrag(Class dummy){super((Class) null);}
/**
Constructs an object to drag the list of URLs in <code>urls.</code>
- The <code>dragSource</code> and <code>name</code> arguments are passed on to QUriDrag,
+ The <code>dragSource</code> and <code>name</code> arguments are passed on to TQUriDrag,
and the list of urls is converted to UTF-8 before being passed
- to QUriDrag.
+ to TQUriDrag.
@param urls the list of URLs
- @param dragSource the parent of the QObject. Should be set when doing drag-n-drop,
+ @param dragSource the parent of the TQObject. Should be set when doing drag-n-drop,
but should be 0 when copying to the clipboard
- @param name the name of the QObject
+ @param name the name of the TQObject
@short Constructs an object to drag the list of URLs in <code>urls.</code>
*/
- public KURLDrag(ArrayList urls, QWidget dragSource, String name) {
+ public KURLDrag(ArrayList urls, TQWidget dragSource, String name) {
super((Class) null);
newKURLDrag(urls,dragSource,name);
}
- private native void newKURLDrag(ArrayList urls, QWidget dragSource, String name);
- public KURLDrag(ArrayList urls, QWidget dragSource) {
+ private native void newKURLDrag(ArrayList urls, TQWidget dragSource, String name);
+ public KURLDrag(ArrayList urls, TQWidget dragSource) {
super((Class) null);
newKURLDrag(urls,dragSource);
}
- private native void newKURLDrag(ArrayList urls, QWidget dragSource);
+ private native void newKURLDrag(ArrayList urls, TQWidget dragSource);
public KURLDrag(ArrayList urls) {
super((Class) null);
newKURLDrag(urls);
@@ -64,15 +64,15 @@ public class KURLDrag extends QUriDrag {
This version also includes metadata.
@param urls the list of URLs
@param metaData a map containing meta data
- @param dragSource the parent of the QObject. Should be set when doing drag-n-drop,
+ @param dragSource the parent of the TQObject. Should be set when doing drag-n-drop,
but should be 0 when copying to the clipboard
- @param name the name of the QObject
+ @param name the name of the TQObject
@short Constructs an object to drag the list of URLs in <code>urls.</code>
@see #metaData
*/
// KURLDrag* KURLDrag(const KURL::List& arg1,const QMap<QString, QString>& arg2,QWidget* arg3,const char* arg4); >>>> NOT CONVERTED
// KURLDrag* KURLDrag(const KURL::List& arg1,const QMap<QString, QString>& arg2,QWidget* arg3); >>>> NOT CONVERTED
// KURLDrag* KURLDrag(const KURL::List& arg1,const QMap<QString, QString>& arg2); >>>> NOT CONVERTED
/**
By default, KURLDrag also exports the URLs as plain text, for e.g. dropping onto a text editor.
But in some cases this might not be wanted, e.g. if using the KURLDrag in a KMultipleDrag
@@ -89,7 +89,7 @@ public class KURLDrag extends QUriDrag {
@short Meta-data to associate with those URLs.
@see TransferJob
*/
- // QMap<QString, QString>& metaData(); >>>> NOT CONVERTED
+ // TQMap<TQString, TQString>& metaData(); >>>> NOT CONVERTED
public native String format(int i);
public native byte[] encodedData(String mime);
/**
@@ -102,7 +102,7 @@ public class KURLDrag extends QUriDrag {
@short Convenience method that decodes the contents of <code>e</code> into a list of KURLs.
*/
- public static native boolean decode(QMimeSourceInterface e, ArrayList urls);
+ public static native boolean decode(TQMimeSourceInterface e, ArrayList urls);
/**
Convenience method that decodes the contents of <code>e</code>
into a list of KURLs and a set of metadata. Decoding will fail if
@@ -115,7 +115,7 @@ public class KURLDrag extends QUriDrag {
@short Convenience method that decodes the contents of <code>e</code> into a list of KURLs and a set of metadata.
*/
// bool decode(const QMimeSource* arg1,KURL::List& arg2,QMap<QString, QString>& arg3); >>>> NOT CONVERTED
/**
Converts a URL to a string representation suitable for dragging.
@short Converts a URL to a string representation suitable for dragging.
@@ -64,15 +64,15 @@ public class KURLDrag extends QUriDrag {
*/
- // KURLDrag* KURLDrag(const KURL::List& arg1,const QMap<QString, QString>& arg2,QWidget* arg3,const char* arg4); >>>> NOT CONVERTED
- // KURLDrag* KURLDrag(const KURL::List& arg1,const QMap<QString, QString>& arg2,QWidget* arg3); >>>> NOT CONVERTED
- // KURLDrag* KURLDrag(const KURL::List& arg1,const QMap<QString, QString>& arg2); >>>> NOT CONVERTED
+ // KURLDrag* KURLDrag(const KURL::List& arg1,const TQMap<TQString, TQString>& arg2,TQWidget* arg3,const char* arg4); >>>> NOT CONVERTED
+ // KURLDrag* KURLDrag(const KURL::List& arg1,const TQMap<TQString, TQString>& arg2,TQWidget* arg3); >>>> NOT CONVERTED
+ // KURLDrag* KURLDrag(const KURL::List& arg1,const TQMap<TQString, TQString>& arg2); >>>> NOT CONVERTED
/**
By default, KURLDrag also exports the URLs as plain text, for e.g. dropping onto a text editor.
@@ -115,7 +115,7 @@ public class KURLDrag extends QUriDrag {
*/
- // bool decode(const QMimeSource* arg1,KURL::List& arg2,QMap<QString, QString>& arg3); >>>> NOT CONVERTED
+ // bool decode(const TQMimeSource* arg1,KURL::List& arg2,TQMap<TQString, TQString>& arg3); >>>> NOT CONVERTED
/**
Converts a URL to a string representation suitable for dragging.